sciduck package
===============

Submodules
----------

sciduck.annotation\_table module
--------------------------------

.. automodule:: sciduck.annotation_table
   :members:
   :undoc-members:
   :show-inheritance:

sciduck.basic\_qc module
------------------------

.. automodule:: sciduck.basic_qc
   :members:
   :undoc-members:
   :show-inheritance:

sciduck.entropy\_qc module
--------------------------

.. automodule:: sciduck.entropy_qc
   :members:
   :undoc-members:
   :show-inheritance:

sciduck.plotting module
-----------------------

.. automodule:: sciduck.plotting
   :members:
   :undoc-members:
   :show-inheritance:

sciduck.templates module
------------------------

.. automodule:: sciduck.templates
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: sciduck
   :members:
   :undoc-members:
   :show-inheritance:
